pub struct BrcodeDecodeInput {
pub code: String,
}Fields
code: StringTrait Implementations
Sourceimpl Clone for BrcodeDecodeInput
impl Clone for BrcodeDecodeInput
Sourcefn clone(&self) -> BrcodeDecodeInput
fn clone(&self) -> BrcodeDecodeInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrcodeDecodeInput
impl Debug for BrcodeDecodeInput
Sourceimpl Default for BrcodeDecodeInput
impl Default for BrcodeDecodeInput
Sourcefn default() -> BrcodeDecodeInput
fn default() -> BrcodeDecodeInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BrcodeDecodeInput
impl<'de> Deserialize<'de> for BrcodeDecodeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrcodeDecodeInput
impl JsonSchema for BrcodeDecodeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrcodeDecodeInput
impl RefUnwindSafe for BrcodeDecodeInput
impl Send for BrcodeDecodeInput
impl Sync for BrcodeDecodeInput
impl Unpin for BrcodeDecodeInput
impl UnsafeUnpin for BrcodeDecodeInput
impl UnwindSafe for BrcodeDecodeInput