pub struct HistoryInput {
pub id: Option<String>,
pub limit: Option<u32>,
}Fields
id: Option<String>limit: Option<u32>Trait Implementations
Sourceimpl Clone for HistoryInput
impl Clone for HistoryInput
Sourcefn clone(&self) -> HistoryInput
fn clone(&self) -> HistoryInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoryInput
impl Debug for HistoryInput
Sourceimpl Default for HistoryInput
impl Default for HistoryInput
Sourcefn default() -> HistoryInput
fn default() -> HistoryInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HistoryInput
impl<'de> Deserialize<'de> for HistoryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HistoryInput
impl JsonSchema for HistoryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HistoryInput
impl RefUnwindSafe for HistoryInput
impl Send for HistoryInput
impl Sync for HistoryInput
impl Unpin for HistoryInput
impl UnsafeUnpin for HistoryInput
impl UnwindSafe for HistoryInput