pub struct PayInput {
pub key: String,
pub amount_cents: i64,
pub note: Option<String>,
pub agent_message: String,
pub request_id: String,
pub idempotency_key: Option<String>,
}Fields
key: Stringamount_cents: i64note: Option<String>agent_message: StringAgent explanation shown to the user during payment approval.
request_id: Stringidempotency_key: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PayInput
impl<'de> Deserialize<'de> for PayInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PayInput
impl JsonSchema for PayInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PayInput
impl RefUnwindSafe for PayInput
impl Send for PayInput
impl Sync for PayInput
impl Unpin for PayInput
impl UnsafeUnpin for PayInput
impl UnwindSafe for PayInput