pub struct McpSetupArgs {
pub client: McpClient,
pub jwt_file: Option<PathBuf>,
pub jwt_stdin: bool,
pub device_id: Option<String>,
pub agent_name: Option<String>,
pub print_only: bool,
}Fields
client: McpClientMCP client target.
jwt_file: Option<PathBuf>Optional path to a JWT file to embed in the generated MCP snippet.
Usually unnecessary for local agents because mcp serve reuses saved CLI credentials.
jwt_stdin: boolRead a JWT from stdin and embed it in the generated MCP snippet.
device_id: Option<String>Optional device identifier override to embed in the generated MCP snippet.
agent_name: Option<String>Optional agent name override to embed in the generated MCP snippet.
print_only: boolOnly print the JSON config without writing to the config file.